@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2021 Clémence Frioux & Arnaud Belcour - Inria Dyliss - Pleiade
+# Copyright (C) 2019-2022 Clémence Frioux & Arnaud Belcour - Inria Dyliss - Pleiade
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -137,7 +137,7 @@ def cli():
     parent_parser_gff_type.add_argument(
         "-gt",
         "--gff-type",
-        help="gff type, by default emapper2gbk search for CDS with gene as Parent in the GFF, but by using the '-gt cds_only' option emapper2gbk will only use the CDS information from the genome",
+        help="gff type, by default emapper2gbk search for CDS with gene as Parent in the GFF, but by using the '-gt cds_only' option emapper2gbk will only use the CDS information from the genome, by using '-gt gmove' emapper2gbk will use mRNA to find CDS, by using 'eggnog' emapper2gbk will use the output ifles of eggnog-mapper",
         required=False,
         type=str
     )
@@ -196,7 +196,7 @@ def cli():
     parent_parser_ete.add_argument(
         "--ete",
         dest="ete",
-        help="use ete3 NCBITaxa instead of query on the EBI Taxonomy Database for taxonomic ID assignation (useful if no itnernet access, except that ete3 NCBITaxa databse msut have been downloaded before).",
+        help="Use ete3 NCBITaxa instead of query on the EBI Taxonomy Database for taxonomic ID assignation (useful if there is no internet access, except that ete3 NCBITaxa database must have been downloaded before).",
         required=False,
         action="store_true",
         default=None,
@@ -216,7 +216,8 @@ def cli():
             parent_parser_go, parent_parser_merge, parent_parser_q, parent_parser_ete
         ],
         description=
-        "Use the annotation of a complete gene catalogue and build gbk files for each set of genes (fna) and proteins (faa) from input directories"
+        "Use the annotation of a complete gene catalogue and build gbk files for each set of genes (fna) and proteins (faa) from input directories",
+        allow_abbrev=False
     )
     genomes_parser = subparsers.add_parser(
         "genomes",
@@ -228,7 +229,8 @@ def cli():
             parent_parser_ete
         ],
         description=
-        "Build a gbk file for each genome with an annotation file for each"
+        "Build a gbk file for each genome with an annotation file for each",
+        allow_abbrev=False
     )
 
     args = parser.parse_args()
